@@ -11,7 +11,7 @@ except ImportError:
 else:
     has_webengine = True
 
-from fuocore import aio
+from feeluown.utils import aio
 
 
 class InvalidCookies(Exception):
@@ -185,7 +185,7 @@ class CookiesLoginDialog(LoginDialog):
     def setup_user(self, user):
         """Setup user session
 
-        :type user: fuocore.models.UserModel
+        :type user: feeluown.models.UserModel
         """
         raise NotImplementedError
 
@@ -193,7 +193,7 @@ class CookiesLoginDialog(LoginDialog):
         """Create a user model from cookies dict
 
         :type cookies: dict
-        :rtype: fuocore.models.UserModel
+        :rtype: feeluown.models.UserModel
         """
         raise NotImplementedError
 
@@ -214,7 +214,7 @@ class CookiesLoginDialog(LoginDialog):
         Generally, you can store the cookies in FeelUOwn data directory
         with specifical filename.
 
-        :type user: fuocore.models.UserModel
+        :type user: feeluown.models.UserModel
         :type cookies: dict
         """
         raise NotImplementedError
